@@ -12,15 +12,14 @@
  ***************************************************************************/
 
 #include "imagewidget.h"
-#include "../config-parley.h"
+#include <config-parley.h>
 
-#include <QtGui/QPainter>
-#include <QtGui/QPaintEngine>
-#include <QtCore/QTimer>
-#include <QtCore/QTimeLine>
+#include <QPainter>
+#include <QPaintEngine>
+#include <QTimer>
+#include <QTimeLine>
 
 #include <QDebug>
-#include <QtWidgets>
 
 #if defined(Q_WS_X11)
 #include <X11/Xlib.h>
